@@ -59,10 +59,15 @@ def create_app(test_config=None): # pylint: disable=too-many-locals
 	register_template_helper(app)
 	setup_navbar(app)
 
-	os.makedirs(app.instance_path, exist_ok=True)
+	# We never want to fail here, but at a file access that doesn't work.
+	# We might only have read access to app.instance_path
+	try:
+		os.makedirs(app.instance_path, exist_ok=True)
+	except: # pylint: disable=bare-except
+		pass
 
 	db.init_app(app)
-	Migrate(app, db, render_as_batch=True)
+	Migrate(app, db, render_as_batch=True, directory='uffd/migrations')
 	# pylint: disable=C0415
 	from uffd import user, selfservice, role, mail, session, csrf, mfa, oauth2, services, signup, rolemod, invite, api
 	# pylint: enable=C0415
